compile_data: Compile datasets

View source: R/compile_data.R

compile_dataR Documentation

Compile datasets

Description

This function takes completed LQT files and compiles analysis-ready datasets

Usage

compile_data(cfg, cores = 1)

Arguments

cfg

a pre-made cfg structure (as list object).

cores

an integer value that indicates how many parallel cores the function should be run on.

Value

A list object containing several analysis-ready datasets, in which rows represent patients and columns represent lesion metrics: "parc.damage", which gives percent regional parcel damage across subjects; "tract.discon", which gives percent tract disconnection across subjects; "net.discon", which gives the percent disconnection for each parcel group or network across its edges; "parc.discon", which gives the percent disconnection for each individual parcel across its edges; "net2net.discon", which gives the percent disconnection of each pairwise network-to-network edge; "parc2parc.discon", which gives the percent disconnection of each pairwise parcel-to-parcel edge.


jdwor/LQT documentation built on Nov. 21, 2023, 4:34 p.m.