get_parcel_cons: Get parcel disconnection measures/maps

View source: R/get_parcel_cons.R

get_parcel_consR Documentation

Get parcel disconnection measures/maps

Description

This is a wrapper function that calls a series of functions to create various parcel disconnection measures. It wraps the 'get_parcel_atlas', 'get_atlas_sspl', 'get_parcel_discon', and 'get_patient_sspl' functions.

Usage

get_parcel_cons(cfg, cores = 1)

Arguments

cfg

a pre-made cfg structure (as list object).

cores

an integer value that indicates how many parallel cores the function should be run on.


jdwor/LQT documentation built on Nov. 21, 2023, 4:34 p.m.