get_parcel_damage: Get parcel damage

View source: R/get_parcel_damage.R

get_parcel_damageR Documentation

Get parcel damage

Description

This function uses an MNI-registered lesion file and an MNI-registered brain parcellation to estimate the amount of damage sustained by each brain region.

Usage

get_parcel_damage(cfg, cores = 1)

Arguments

cfg

a pre-made cfg structure (as list object).

cores

an integer value that indicates how many parallel cores the function should be run on.

Value

A .nii.gz file with the suffix _percent_damage.nii.gz. This file contains a damage.map in which voxel values correspond to the a .csv file with the suffix _percent_damage.csv. This file contains a data frame with


jdwor/LQT documentation built on Nov. 21, 2023, 4:34 p.m.