get_tract_discon: Get tract-based disconnection

View source: R/get_tract_discon.R

get_tract_disconR Documentation

Get tract-based disconnection

Description

This function computes tract-based disconnection measures using an MNI-registered lesion and the tract segmentations obtained from the curated HCP-842 tractography atlas as described in Yeh et al., (2018 - NeuroImage).

Usage

get_tract_discon(cfg, cores = 1)

Arguments

cfg

a pre-made cfg structure (as list object).

cores

an integer value that indicates how many parallel cores the function should be run on.

Value

A .csv file giving the percent of streamlines in each tract that were disconnected by the lesions (column "Discon") and the associated tract names (column "Tract").


jdwor/LQT documentation built on Nov. 21, 2023, 4:34 p.m.