plot_lqt_subject: Plot subject-level summaries

View source: R/plot_lqt_subject.R

plot_lqt_subjectR Documentation

Plot subject-level summaries

Description

This function constructs subject-level visualizations of lesion-based damage and disconnection

Usage

plot_lqt_subject(cfg, subject = 1, type = NULL)

Arguments

cfg

a pre-made cfg structure (as list object).

subject

either a string giving a subject ID, or an integer giving the subject index.

type

a string specifying the desired plot type. Options are "parcel.damage", which gives a barplot of percent parcel damage; "tract.discon", which gives a barplot of percent tract-level disconnection; "parcel.discon", which gives a barplot and brain network plots showing parcel-level disconnection; and "parcel.sspl", which gives a barplot and brain network plots showing parcel-level structural shortest path length increases.

Value

A plot object visualizing either parcel damage (type = 'parcel.damage'), tract disconnection (type = 'tract.discon'), i nter/intra-parcel structural disconnection (type = 'parcel.discon'), or changes in inter-parcel structural shortest path lengths (type = 'parcel.sspl').


jdwor/LQT documentation built on Nov. 21, 2023, 4:34 p.m.