View source: R/get_parcel_cons.R
| get_parcel_cons | R Documentation |
This is a wrapper function that calls a series of functions to create various parcel disconnection measures. It wraps the 'get_parcel_atlas', 'get_atlas_sspl', 'get_parcel_discon', and 'get_patient_sspl' functions.
get_parcel_cons(cfg, cores = 1)
cfg |
a pre-made cfg structure (as list object). |
cores |
an integer value that indicates how many parallel cores the function should be run on. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.