View source: R/get_parcel_damage.R
| get_parcel_damage | R Documentation |
This function uses an MNI-registered lesion file and an MNI-registered brain parcellation to estimate the amount of damage sustained by each brain region.
get_parcel_damage(cfg, cores = 1)
cfg |
a pre-made cfg structure (as list object). |
cores |
an integer value that indicates how many parallel cores the function should be run on. |
A .nii.gz file with the suffix _percent_damage.nii.gz. This file contains a damage.map in which voxel values correspond to the a .csv file with the suffix _percent_damage.csv. This file contains a data frame with
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.