View source: R/get_tract_discon.R
| get_tract_discon | R Documentation |
This function computes tract-based disconnection measures using an MNI-registered lesion and the tract segmentations obtained from the curated HCP-842 tractography atlas as described in Yeh et al., (2018 - NeuroImage).
get_tract_discon(cfg, cores = 1)
cfg |
a pre-made cfg structure (as list object). |
cores |
an integer value that indicates how many parallel cores the function should be run on. |
A .csv file giving the percent of streamlines in each tract that were disconnected by the lesions (column "Discon") and the associated tract names (column "Tract").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.